<?php
/**
 *
 * @package Announcement Topics Extension
 * @copyright (c) 2017 Ovelissimo
 * @license GNU General Public License, version 2 (GPL-2.0)
 *
 * Based on the original Recent Topics by PayBas (recenttopics)
 */

namespace ovelissimo\announcementtopics\acp;

/**
 * Class announcementtopics_module
 *
 * @package ovelissimo\announcementtopics\acp
 */
class announcementtopics_module
{
	public $u_action;

	/**
	 * @param $id
	 * @param $mode
	 */
	public function main($id, $mode)
	{
		global $config, $phpbb_extension_manager, $request, $template, $user, $db;

		$user->add_lang(array('acp/common', 'ucp', 'viewforum'));
		$this->tpl_name = 'acp_announcementtopics';
		$this->page_title = $user->lang('ANNOUNCEMENT_TOPICS');

		$form_key = 'acp_announcementtopics';
		add_form_key($form_key);

		if ($request->is_set_post('submit'))
		{
			if (!check_form_key($form_key))
			{
				trigger_error($user->lang('FORM_INVALID') . adm_back_link($this->u_action), E_USER_WARNING);
			}

			/*
			* acp options for everyone
			*/
			$at_number = $request->variable('at_number', 5);
			$config->set('at_number', $at_number);

			$at_page_number = $request->variable('at_page_number', '');
			$config->set('at_page_number', $at_page_number == 'on' ? 1 : 0 );

			$at_min_topic_level = $request->variable('at_min_topic_level', 2);
			$config->set('at_min_topic_level', $at_min_topic_level);

			// variable should be '' as it is a string ("1, 2, 3928") here, not an integer.
			$at_anti_topics = $request->variable('at_anti_topics', '');
			$config->set('at_anti_topics', $at_anti_topics);

			$at_parents = $request->variable('at_parents', false);
			$config->set('at_parents', $at_parents);

			// Enable on other extension pages?
			$at_on_newspage = $request->variable('at_on_newspage', 0);
			$config->set('at_on_newspage', $at_on_newspage);

			/*
			 *  default positions, modifiable by ucp
	         */
			$at_enable = $request->variable('at_enable', 0);
			$config->set('at_index', $at_enable);

			$at_location = $request->variable('at_location', '');
			$config->set('at_location', $at_location);

			$at_sort_start_time = $request->variable('at_sort_start_time', false);
			$config->set('at_sort_start_time', $at_sort_start_time);

			$at_unread_only = $request->variable('at_unread_only', false);
			$config->set('at_unread_only', $at_unread_only);

			trigger_error($user->lang('CONFIG_UPDATED') . adm_back_link($this->u_action));
		}

		$sql='';
		//reset user preferences
		if ($request->is_set_post('at_reset_default'))
		{
			$at_unread_only = isset($config['at_unread_only']) ? ($config['at_unread_only']=='' ? 0 :$config['at_unread_only'])  : 0;
			$at_sort_start_time = isset($config['at_sort_start_time']) ?  ($config['at_sort_start_time']=='' ? 0 : $config['at_sort_start_time'])  : 0;
			$at_enable =  isset($config['at_index']) ? ($config['at_index']== '' ? 0 : $config['at_index']) : 0;
			$at_location = $config['at_location'];

			$sql = 'UPDATE ' . USERS_TABLE . " SET
			user_at_enable = '" . (int) $at_enable . "',
			user_at_sort_start_time = '" . (int) $at_sort_start_time . "',
			user_at_unread_only = '" . (int) $at_unread_only . "',
			user_at_location =  '" . $at_location . "'" ;

			$db->sql_query($sql);
		}

		$topic_types = array (
			2 => $user->lang('ANNOUNCEMENTS'),
			3 => $user->lang('GLOBAL_ANNOUNCEMENT'),
		);

		foreach ($topic_types as $key => $topic_type)
		{
			$template->assign_block_vars(
				'topiclevel_row',
				array(
					'VALUE'    => $key,
					'SELECTED' => ($config['at_min_topic_level'] == $key) ? 'selected="selected"' : '',
					'OPTION'   => $topic_type,
				)
			);
		}

		$display_types = array (
			'AT_TOP'    => $user->lang('AT_TOP'),
			'AT_BOTTOM' => $user->lang('AT_BOTTOM'),
			'AT_SIDE'   => $user->lang('AT_SIDE'),
		);

		foreach ($display_types as $key => $display_type)
		{
			$template->assign_block_vars(
				'AT_location_row',
				array(
					'VALUE'    => $key,
					'SELECTED' => ($config['at_location'] == $key) ? 'selected="selected"' : '',
					'OPTION'   => $display_type,
				)
			);
		}

		$template->assign_vars(
			array(
				'AT_ANTI_TOPICS'     => isset($config['at_anti_topics']) ? $config['at_anti_topics'] : '',
				'AT_NUMBER'          => isset($config['at_number']) ? $config['at_number'] : '',
				'AT_PAGE_NUMBER'     => ((isset($config['at_page_number']) ? $config['at_page_number'] : '') == '1') ? 'checked="checked"' : '',
				'AT_PARENTS'         => isset($config['at_parents']) ? $config['at_parents'] : false,
				'AT_UNREAD_ONLY'     => isset($config['at_unread_only']) ? $config['at_unread_only'] : false,
				'AT_SORT_START_TIME' => isset($config['at_sort_start_time']) ? $config['at_sort_start_time'] : false,
				'AT_INDEX'           => isset($config['at_index']) ? $config['at_index'] : false,
				'AT_ON_NEWSPAGE'     => isset($config['at_on_newspage']) ? $config['at_on_newspage'] : false,
				'S_AT_NEWSPAGE'      => $phpbb_extension_manager->is_enabled('nickvergessen/newspage'),
				'U_ACTION'           => $this->u_action,
			)
		);
	}
}
