<?php
/**
 *
 * @package Announcement Topics Extension
 * @copyright (c) 2015 Ovelissimo
 * @license GNU General Public License, version 2 (GPL-2.0)
 *
 * Based on the original Recent Topics by PayBas (recenttopics)
 */

namespace ovelissimo\announcementtopics\event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * An EventSubscriber knows himself what events he is interested in.
 * If an EventSubscriber is added to an EventDispatcherInterface, the manager invokes
 * {@link getSubscribedEvents} and registers the subscriber as a listener for all
 * returned events.
 *
 * @author Guilherme Blanco <guilhermeblanco@hotmail.com>
 * @author Jonathan Wage <jonwage@gmail.com>
 * @author Roman Borschel <roman@code-factory.org>
 * @author Bernhard Schussek <bschussek@gmail.com>
 */
class ucp_listener implements EventSubscriberInterface
{
	/**
 * @var \phpbb\auth\auth
*/
	protected $auth;

	/**
 * @var \phpbb\config\config
*/
	protected $config;

	/**
 * @var \phpbb\request\request
*/
	protected $request;

	/**
 * @var \phpbb\template\template
*/
	protected $template;

	/**
 * @var \phpbb\user
*/
	protected $user;

	/**
	 * ucp_listener constructor.
	 *
	 * @param \phpbb\auth\auth         $auth
	 * @param \phpbb\config\config     $config
	 * @param \phpbb\request\request   $request
	 * @param \phpbb\template\template $template
	 * @param \phpbb\user              $user
	 */
	public function __construct(\phpbb\auth\auth $auth, \phpbb\config\config $config, \phpbb\request\request $request, \phpbb\template\template $template, \phpbb\user $user)
	{
		$this->auth = $auth;
		$this->config = $config;
		$this->request = $request;
		$this->template = $template;
		$this->user = $user;
	}

	/**
	 * @return array
	 */
	static public function getSubscribedEvents()
	{
		return array(
		'core.ucp_prefs_view_data'        => 'ucp_prefs_get_data',
		'core.ucp_prefs_view_update_data' => 'ucp_prefs_set_data',
		);
	}

	/**
	 * @param $event
	 */
	public function ucp_prefs_get_data($event)
	{
		// Request the user option vars and add them to the data array
		$event['data'] = array_merge(
			$event['data'], array(
			'at_enable'          => $this->request->variable('at_enable', (int) $this->user->data['user_at_enable']),
			'at_location'        => $this->request->variable('at_location', $this->user->data['user_at_location']),
			'at_sort_start_time' => $this->request->variable('at_sort_start_time', (int) $this->user->data['user_at_sort_start_time']),
			'at_unread_only'     => $this->request->variable('at_unread_only', (int) $this->user->data['user_at_unread_only']),
			)
		);

		// Output the data vars to the template (except on form submit)
		if (!$event['submit'] && $this->auth->acl_get('u_at_view'))
		{
			$this->user->add_lang_ext('ovelissimo/announcementtopics', 'announcementtopics_ucp');
			$template_vars = array();

			if ($this->auth->acl_get('u_at_enable') || $this->auth->acl_get('u_at_location') || $this->auth->acl_get('u_at_sort_start_time') || $this->auth->acl_get('u_at_unread_only'))
			{
				$template_vars += array(
				'S_AT_SHOW' => true,
				);
			}

			if ($this->auth->acl_get('u_at_enable'))
			{
				$template_vars += array(
				'A_AT_ENABLE' => true,
				'S_AT_ENABLE' => $event['data']['at_enable'],
				);
			}

			if ($this->auth->acl_get('u_at_sort_start_time'))
			{
				$template_vars += array(
				'A_AT_SORT_START_TIME' => true,
				'S_AT_SORT_START_TIME' => $event['data']['at_sort_start_time'],
				);
			}

			if ($this->auth->acl_get('u_at_unread_only'))
			{
				$template_vars += array(
				'A_AT_UNREAD_ONLY' => true,
				'S_AT_UNREAD_ONLY' => $event['data']['at_unread_only'],
				);
			}

			if ($this->auth->acl_get('u_at_location'))
			{

				$template_vars += array(
					'A_AT_LOCATION' => true,
				);

				$display_types = array (
					'AT_TOP'    => $this->user->lang('AT_TOP'),
					'AT_BOTTOM' => $this->user->lang('AT_BOTTOM'),
					'AT_SIDE'   => $this->user->lang('AT_SIDE'),
				);

				foreach ($display_types as $key => $display_type)
				{
					$this->template->assign_block_vars(
						'AT_location_row',
						array(
							'VALUE'    => $key,
							'SELECTED' => ($event['data']['at_location'] == $key) ? 'selected="selected"' : '',
							'OPTION'   => $display_type,
						)
					);
				}
			}

			$this->template->assign_vars($template_vars);
		}
	}

	/**
	 * @param $event
	 */
	public function ucp_prefs_set_data($event)
	{
		$event['sql_ary'] = array_merge(
			$event['sql_ary'], array(
			'user_at_enable'          => $event['data']['at_enable'],
			'user_at_location'        => $event['data']['at_location'],
			'user_at_sort_start_time' => $event['data']['at_sort_start_time'],
			'user_at_unread_only'     => $event['data']['at_unread_only'],
			)
		);
	}
}
