<?php
/**
 *
 * @package Announcement Topics Extension
 * @copyright (c) 2015 Ovelissimo
 * @license GNU General Public License, version 2 (GPL-2.0)
 *
 * Based on the original Recent Topics by PayBas (recenttopics)
 */

namespace ovelissimo\announcementtopics\migrations;

class release_1_0_0 extends \phpbb\db\migration\migration
{

	public function effectively_installed()
	{
		return isset($this->config['at_version']) && version_compare($this->config['at_version'], '1.0.0', '>=');
	}

	public function update_schema()
	{
		return array(
			'add_columns' => array(
				$this->table_prefix . 'forums' => array(
					'forum_announcement_topics' => array('TINT:1', 1),
				),
				$this->table_prefix . 'users' => array(
					'user_at_enable'          => array('BOOL', 1),
					'user_at_location'        => array('VCHAR:10', 'AT_TOP'),
					'user_at_sort_start_time' => array('BOOL', 0),
					'user_at_unread_only'     => array('BOOL', 0),
				),
			),
		);
	}

	public function revert_schema()
	{
		return array(
			'drop_columns' => array(
				$this->table_prefix . 'forums' => array(
					'forum_announcement_topics',
				),
				$this->table_prefix . 'users' => array(
					'user_at_enable',
					'user_at_location',
					'user_at_sort_start_time',
					'user_at_unread_only',
				),
			),
		);
	}

	public function update_data()
	{
		return array(

			// Add new config vars
			array('config.add', array('at_version', '1.0.0')),
			array('config.add', array('at_number', 5)),
			array('config.add', array('at_page_number', 0)),
			array('config.add', array('at_anti_topics', 0)),
			array('config.add', array('at_parents', 1)),
			array('config.add', array('at_unread_only', 0)),
			array('config.add', array('at_index', 1)),
			array('config.add', array('at_min_topic_level', 0)),
			array('config.add', array('at_on_newspage', 0)),
			array('config.add', array('at_sort_start_time', 0)),
			array('config.add', array('at_location', 'AT_TOP')),
			
			array('custom', array(array($this, 'update_default_loc'))),
			
			array('permission.add', array('u_at_view')),
			array('permission.add', array('u_at_enable')),
			array('permission.add', array('u_at_location')),
			array('permission.add', array('u_at_sort_start_time')),
			array('permission.add', array('u_at_unread_only')),
			
			array('permission.permission_set', array('REGISTERED', 'u_at_view', 'group')),
			array('permission.permission_set', array('ROLE_USER_FULL', 'u_at_enable')),
			array('permission.permission_set', array('ROLE_USER_FULL', 'u_at_location')),
			array('permission.permission_set', array('ROLE_USER_FULL', 'u_at_sort_start_time')),
			array('permission.permission_set', array('ROLE_USER_FULL', 'u_at_unread_only')),
			array('permission.permission_set', array('GUESTS', 'u_at_view', 'group')),

			array('if', array(
				array('module.exists', array('acp', 'ACP_CAT_DOT_MODS', 'ANNOUNCEMENT_TOPICS_EXT')),
				array('module.remove', array('acp', 'ACP_CAT_DOT_MODS', 'ANNOUNCEMENT_TOPICS_EXT')),
			)),

			// Add new modules
			array('module.add', array(
				'acp',
				'ACP_CAT_DOT_MODS',
				'ANNOUNCEMENT_TOPICS'
			)),

			array('module.add', array(
				'acp',
				'ANNOUNCEMENT_TOPICS',
				array(
					'module_basename'    => '\ovelissimo\announcementtopics\acp\announcementtopics_module',
					'modes'    => array('announcementtopics_config'),
				),
			)),
		);
	}

	public function revert_data()
	{
		return array(
			array('config.remove', array('at_version')),
			array('config.remove', array('at_number')),
			array('config.remove', array('at_page_number')),
			array('config.remove', array('at_anti_topics')),
			array('config.remove', array('at_parents')),
			array('config.remove', array('at_unread_only')),
			array('config.remove', array('at_unreadonly')),
			array('config.remove', array('at_index')),
			array('config.remove', array('at_min_topic_level')),
			array('config.remove', array('at_on_newspage')),
			array('config.remove', array('at_sort_start_time')),
			array('config.remove', array('at_location')),
			
			array('permission.remove', array('u_at_view')),
			array('permission.remove', array('u_at_enable')),
			array('permission.remove', array('u_at_location')),
			array('permission.remove', array('u_at_sort_start_time')),
			array('permission.remove', array('u_at_unread_only')),

			array('module.remove', array(
				'acp',
				'ANNOUNCEMENT_TOPICS',
				array(
					'module_basename'    => '\ovelissimo\announcementtopics\acp\announcementtopics_module',
					'modes'    => array('announcementtopics_config'),
				),
			)),
			array('module.remove', array(
				'acp',
				'ACP_CAT_DOT_MODS',
				'ANNOUNCEMENT_TOPICS'
			)),
		);
	}
	
	public function update_default_loc()
	{
		$at_location = 'AT_TOP';
		$this->config->set('at_location', $at_location);
		$sql = 'UPDATE ' . USERS_TABLE . " SET user_at_location = '" . $at_location . "' ";
		$this->db->sql_query($sql);
	}
}
